/*
 * This file is part of the MicroPython project, http://micropython.org/
 *
 * The MIT License (MIT)
 *
 * Copyright (c) 2018 Scott Shawcroft for Adafruit Industries LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
#ifndef MICROPY_INCLUDED_SUPERVISOR_SHARED_EXTERNAL_FLASH_DEVICES_H
#define MICROPY_INCLUDED_SUPERVISOR_SHARED_EXTERNAL_FLASH_DEVICES_H

{% for device in nvms %}
#define {{ device.sku }} { \
        .total_size = {{ device.total_size }}, \
        .start_up_time_us = {{ device.start_up_time_us }}, \
        .manufacturer_id = {{ device.manufacturer_id }}, \
        .memory_type = {{ device.memory_type }}, \
        .capacity = {{ device.capacity }}, \
        .max_clock_speed_mhz = {{ device.max_clock_speed_mhz }}, \
        .quad_enable_bit_mask = {{ device.quad_enable_bit_mask }}, \
        .has_sector_protection = {{ device.has_sector_protection | lower() }}, \
        .supports_fast_read = {{ device.supports_fast_read | lower() }}, \
        .supports_qspi = {{ device["6b_quad_read"] | lower() }}, \
        .supports_qspi_writes = {{ device["32_qspi_write"] | lower() }}, \
        .write_status_register_split = {{ device.write_status_register_split | lower() }}, \
        .single_status_byte = {{ (device.quad_enable_status_byte == 1) | lower() }}, \
}
{% endfor %}

#endif  // MICROPY_INCLUDED_SUPERVISOR_SHARED_EXTERNAL_FLASH_DEVICES_H
